@@ -284,6 +284,9 @@ module YARD
 
       # @return [Integer] the object's hash value (for equality checking)
       def hash; path.hash end
+      
+      # @return [nil] this object does not turn into an array
+      def to_ary; nil end
 
       # Accesses a custom attribute on the object
       # @param [#to_s] key the name of the custom attribute
@@ -336,7 +339,6 @@ module YARD
       #   as a +String+ for the definition of the code object only (not the block)
       def source=(statement)
         if statement.respond_to?(:source)
-          self.line = statement.line
           self.signature = statement.first_line
           @source = format_source(statement.source.strip)
         else
